==> haskell-annotated-wl-pprint-0.7.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
key: annotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: 771c2426e5b31ca1c611532159e1ef8e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI
key: annotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI
license: BSD-3-Clause
maintainer: david@davidchristiansen.dk
author: Daan Leijen, David Raymond Christiansen
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
abi: db836935fecb8b8f1c87aaa649583d2a
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
import-dirs: /usr/lib/ghc-8.4.2/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-5EJhaPPvnKODWMqVOHKqvI
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
